@@ -15,4 +15,15 @@ from .tikos import (Description,
                     GetGraph,
                     GetGraphRelationships,
                     GetGraphRetrieval,
-                    GetGraphRetrievalWithDS)
+                    GetGraphRetrievalWithDS,
+                    GetCustomerGraphRetrievalWithDS,
+                    BuildSC,
+                    GetSimilarCase,
+                    GetGraphStructurePerDoc,
+                    GenerateGraphPerDoc,
+                    GenerateAutoGraph,
+                    GetReasoning,
+                    UploadModel,
+                    UploadModelConfig,
+                    UploadModelCaseData,
+                    ProcessModel)
